#' ---
#' title: "Analysis of Rhymth Memory data"
#' output: 
#'   html_document:
#'     self_contained: false
#' ---

#+ message = FALSE, echo = FALSE
library(ggplot2)
library(scales)
library(plyr)
library(magrittr)
library(knitr)
library(ggExtra)
library(psych)
library(lme4)
library(lmerTest)
library(rethinking) # From https://github.com/rmcelreath/rethinking
options(digits=5)



d <- read.csv("subject_info_with_extra_variables_all_data.csv", stringsAsFactors=FALSE)
d <- d[! is.na(d$digit_span_correct),]
tapping <- read.csv("tapping_per_cond_all_data.csv", stringsAsFactors=FALSE)
tapping <- merge(tapping, d[,c("subject", "slow_mt", "digit_span_correct", "rhythm_span_score")])


#' # Summary statistics

ldply(d[, c("subject", "digit_span_correct", "digit_span_largest","slow_mt", "bayes_mu.500")], function(variable) data.frame(n = sum(!is.na(variable))))

sum_stat <- ldply(d[,c("age", "year_music", "digit_span_correct", "digit_span_largest","slow_mt", "rhythm_span_score", 
           "bayes_sigma.500", "bayes_sigma.1000", "bayes_sigma.2000", "bayes_sigma.3000"),], 
 function(x) {
   x <- na.omit(x)
  data.frame(median = median(x), lower_quartile = quantile(x, 0.25),upper_quartile = quantile(x, 0.75),
             min = min(x), max = max(x), mean=mean(x), sd=sd(x))
})

kable(sum_stat)

table(d$sex)

table(d$instrument)

year_practice <- d$year_music[d$instrument == "y"]
mean(year_practice)
sd(year_practice)
#' # Digitspan vs Rhythm span

cor.test(log(d$digit_span_correct), log(d$rhythm_span_score))

# median rhythm span score
median_digit_span <- median( d$digit_span_correct)
# Digit span below median
median(d$rhythm_span_score[ d$digit_span_correct < median_digit_span])
# Digit span above median
median(d$rhythm_span_score[ d$digit_span_correct >= median_digit_span])
4.917 - 3.75


#+ rhythm_span_vs_digit_span, fig.width=5.5, fig.height=5.5, dpi = 150
x <- log(d$digit_span_correct)
y <- log(d$rhythm_span_score)

old.par <- par(no.readonly = TRUE)
xrange <- range(x, na.rm = TRUE) + diff(range(x, na.rm = TRUE)) * c(-0.06, 0.02)
yrange <- range(y, na.rm = TRUE) + diff(range(y, na.rm = TRUE)) * c(-0.14, 0.02)
xhist <- hist(x, breaks = seq(xrange[1], xrange[2], length.out = 8), plot = FALSE)
yhist <- hist(y, breaks = seq(yrange[1], yrange[2], length.out = 8), plot = FALSE)
nf <- layout(matrix(c(2, 4, 1, 3), 2, 2, byrow = TRUE), c(3, 
    1), c(1, 3), TRUE)
par(mar = c(5, 4, 1, 1))
plot(x, y, xlim = xrange, ylim = yrange, xaxt = "n", yaxt = "n", xlab="Digit span score", ylab="Rhythm span score")
axis(1, at = log(seq(1, 15, 2)), labels = seq(1, 15, 2))
axis(2, at = log(seq(1, 18, 1)), labels = seq(1, 18, 1))

ellipses(x, y, add = TRUE, smooth = FALSE)
text(log(12.2), log(2.6), expression("Pearson's" ~ italic(r) ~ " = .48, " ~ italic(p) ~ "< .005"))
par(mar = c(0, 4, 2, 1))
mp <- barplot(xhist$counts, axes = TRUE, space = 0, ylab = "Count", yaxt = "n")
axis(side = 2, at =  c(0, 5, 10))
par(mar = c(5, 0, 1, 2))
mp <- barplot(yhist$counts, axes = TRUE, space = 0, horiz = TRUE, xlab = "Count", xaxt = "n")
axis(side = 1, at =  c(0, 5, 10))
par(old.par)

#' # Slow motor tempo stats

#+ slow_motor_tempo_hist, fig.width=5.5, fig.height=3 , dpi = 150
old_par <- par(mar = c(4.2, 4.1, 1, 1))
hist(log(d$slow_mt), seq(log(1000), log(8000), length.out = 10), col = "lightblue",xlim=c(log(1000), log(8000)), 
     xaxt="n", yaxt="n",ylab="Count", xlab="Slow motor tempo in ms", main="")
steps <-  c(1000, 1500, 2000, 3000,4000, 6000)
axis(1, log(steps), steps)
axis(2, c(0, 5, 10))
par(old_par)

cor.test(log(d$digit_span_correct), log(d$slow_mt))
cor.test(log(d$rhythm_span_score), log(d$slow_mt))

fit <- lmerTest::lmer(log(bayes_sigma) ~ 1 + scale(isi) * scale(log(slow_mt)) + (1 + scale(isi) | subject) , data=tapping)
summary(fit)
fit <- lme4::lmer(log(bayes_sigma) ~ 1 + scale(isi) * scale(log(slow_mt)) + (1 + scale(isi) | subject) , data=tapping)
precis(fit, prob = 0.95)

#+ slow_motor_tempo_vs_tapping, fig.width=5.5, fig.height=4.5
slow_mt_median <- median(d$slow_mt, na.rm = TRUE)
qplot(scale(isi), log(bayes_sigma), color = slow_mt > slow_mt_median, geom=c("point", "smooth"), method="lm",data=tapping) 

#' # Rhythm Spans vs tapping

formula_rhythm <- log(bayes_sigma) ~ 1 + scale(isi) * scale(log(rhythm_span_score)) + (1 + scale(isi) | subject)
fit_rhythm <- lmerTest::lmer(formula_rhythm , data=tapping)
fit_sum <- summary(fit_rhythm)
fit_sum
fit_rhythm <- lme4::lmer(formula_rhythm, data=tapping)
kable(precis(fit_rhythm, prob = 0.95)@output)
kable(fit_sum$coefficients)


rhythm_quartiles <- quantile(d$rhythm_span_score, c(0.25, 0.75))

pred_data <- expand.grid(isi = unique(tapping$isi), 
                        rhythm_span_score = rhythm_quartiles)

pred_data$log_sigma <- predict(fit_rhythm, pred_data, re.form = ~0)
 
rhythm_span_score_median <- median(d$rhythm_span_score, na.rm = TRUE)
tapping$above_median_rhythm_span <- tapping$rhythm_span_score > rhythm_span_score_median
pred_data$above_median_rhythm_span <- pred_data$rhythm_span_score > rhythm_span_score_median

#+ rhythm_span_vs_tapping, fig.width=5, fig.height=4, dpi = 150

qplot(isi, bayes_sigma, color = above_median_rhythm_span, shape  = above_median_rhythm_span, fill = above_median_rhythm_span,
      linetype = above_median_rhythm_span, position = position_jitterdodge(jitter.width = 125, dodge.width = 350), geom="point", data=tapping) +
  geom_line(aes(y = exp(log_sigma)), data=pred_data) + 
  scale_y_log10("Asynchrony SD in ms", breaks=c(25, 50, 100, 200)) +
  scale_x_continuous("Interstimulus interval in ms", breaks = unique(tapping$isi)) +
  scale_fill_hue("Rhythm span is", breaks = c(FALSE, TRUE), labels = c("below median", "above median")) +
  scale_color_discrete("Rhythm span is", breaks = c(FALSE, TRUE), labels = c("below median", "above median")) +
  scale_shape_discrete("Rhythm span is", breaks = c(FALSE, TRUE), labels = c("below median", "above median")) +
  scale_linetype_discrete("Rhythm span is", breaks = c(FALSE, TRUE), labels = c("below median", "above median")) +
  theme_bw() + theme(legend.justification=c(0,1), legend.position=c(0,1))


#' # Digit Span vs tapping

formula_digit <- log(bayes_sigma) ~ 1 + scale(isi) * scale(log(digit_span_correct)) + (1 + scale(isi) | subject)
fit_digit <- lmerTest::lmer(formula_digit , data=tapping)
fit_sum <- summary(fit_digit)
fit_digit <- lme4::lmer(formula_digit , data=tapping)
kable(precis(fit_digit, prob = 0.95)@output)
kable(fit_sum$coefficients)
fit_sum

digit_quartiles <- quantile(d$digit_span_correct, c(0.25, 0.75))

pred_data <- expand.grid(isi = unique(tapping$isi), 
                        digit_span_correct = digit_quartiles)

pred_data$log_sigma <- predict(fit_digit, pred_data, re.form = ~0)
 
digit_span_correct_median <- median(d$digit_span_correct, na.rm = TRUE)
tapping$above_median_digit_span<- tapping$digit_span_correct > digit_span_correct_median
pred_data$above_median_digit_span <- pred_data$digit_span_correct > digit_span_correct_median


#+ digit_span_vs_tapping, fig.width=5, fig.height=4, dpi = 150
qplot(isi, bayes_sigma, color = above_median_digit_span, shape = above_median_digit_span, fill = above_median_digit_span,
      linetype = above_median_digit_span, position = position_jitterdodge(jitter.width = 125, dodge.width = 350), geom=c("point"),data=tapping) +
  geom_line(aes(y = exp(log_sigma)), data=pred_data) + 
  scale_y_log10("Asynchrony SD in ms", breaks=c(25, 50, 100, 200)) +
  scale_x_continuous("Interstimulus interval in ms", breaks = unique(tapping$isi)) +
    scale_fill_hue("Digit span is", breaks = c(FALSE, TRUE), labels = c("below median", "above median")) +
  scale_color_discrete("Digit span is", breaks = c(FALSE, TRUE), labels = c("below median", "above median")) +
  scale_shape_discrete("Digit span is", breaks = c(FALSE, TRUE), labels = c("below median", "above median")) +
  scale_linetype_discrete("Digit span is", breaks = c(FALSE, TRUE), labels = c("below median", "above median")) +
  theme_bw() + theme(legend.justification=c(0,1), legend.position=c(0,1))

#' # Some extra stuff

#+ tapping_pairs_plot
pairs(d[,c("bayes_sigma.500", "bayes_sigma.1000", "bayes_sigma.2000", "bayes_sigma.3000")], log = "xy")
#+ tapping_corr_plot
cor.plot(cor(log(d[,c("bayes_sigma.500", "bayes_sigma.1000", "bayes_sigma.2000", "bayes_sigma.3000")]), use = "complete.obs") )
corr.test(log(d[,c("bayes_sigma.500", "bayes_sigma.1000", "bayes_sigma.2000", "bayes_sigma.3000")]))
